import { Subject } from 'rxjs';
import { DashboardViewBase } from '@/studio-core';
import ContactService from '@/service/contact/contact-service';
import PortalViewEngine from '@engine/view/portal-view-engine';

/**
 * 联系人数据看板视图视图基类
 *
 * @export
 * @class ContactSummaryViewBase
 * @extends {DashboardViewBase}
 */
export class ContactSummaryViewBase extends DashboardViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof ContactSummaryViewBase
     */
    protected appDeName: string = 'contact';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof ContactSummaryViewBase
     */
    protected appDeKey: string = 'contactid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof ContactSummaryViewBase
     */
    protected appDeMajor: string = 'fullname';

    /**
     * 实体服务对象
     *
     * @type {ContactService}
     * @memberof ContactSummaryViewBase
     */
    protected appEntityService: ContactService = new ContactService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof ContactSummaryViewBase
     */    
    protected counterServiceArray: Array<any> = [];

	/**
	 * 自定义视图导航上下文集合
	 *
     * @protected
	 * @type {*}
	 * @memberof ContactSummaryViewBase
	 */
    protected customViewNavContexts: any = {
        'REGARDINGOBJECTID': { isRawValue: false, value: 'contact' },
        'REGARDINGOBJECTTYPECODE': { isRawValue: true, value: 'CONTACT' }
    };

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof ContactSummaryViewBase
     */
    protected model: any = {
        srfCaption: 'entities.contact.views.summaryview.caption',
        srfTitle: 'entities.contact.views.summaryview.title',
        srfSubTitle: 'entities.contact.views.summaryview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof ContactSummaryViewBase
     */
    protected containerModel: any = {
        view_dashboard: { name: 'dashboard', type: 'DASHBOARD' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '6168a7e787ead13b1e0f9a55007bc68c';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof ContactSummaryViewBase
     */
    public engine: PortalViewEngine = new PortalViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof ContactSummaryViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            dashboard: this.$refs.dashboard,
            keyPSDEField: 'contact',
            majorPSDEField: 'fullname',
            isLoadDefault: true,
        });
    }

    /**
     * dashboard 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof ContactSummaryViewBase
     */
    public dashboard_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('dashboard', 'load', $event);
    }


}